@@ -59,14 +59,20 @@ typedef struct _GstVaapiBufferProxy             GstVaapiBufferProxy;
 
 /**
  * GstVaapiBufferMemoryType:
- * @GST_VAAPI_BUFFER_MEMORY_TYPE_DMA_BUF: DRM PRIME buffer memory type.
+ * @GST_VAAPI_BUFFER_MEMORY_TYPE_DMA_BUF: DRM PRIME buffer memory type (old version).
+ * @GST_VAAPI_BUFFER_MEMORY_TYPE_DMA_BUF2: DRM PRIME buffer memory type.
  * @GST_VAAPI_BUFFER_MEMORY_TYPE_GEM_BUF: Kernel DRM buffer memory type.
+ * @GST_VAAPI_BUFFER_MEMORY_TYPE_V4L2: V4L2 buffer memory type.
+ * @GST_VAAPI_BUFFER_MEMORY_TYPE_USER_PTR: User pointer memory type.
  *
  * Set of underlying VA buffer memory types.
  */
 typedef enum {
   GST_VAAPI_BUFFER_MEMORY_TYPE_DMA_BUF = 1,
+  GST_VAAPI_BUFFER_MEMORY_TYPE_DMA_BUF2,
   GST_VAAPI_BUFFER_MEMORY_TYPE_GEM_BUF,
+  GST_VAAPI_BUFFER_MEMORY_TYPE_V4L2,
+  GST_VAAPI_BUFFER_MEMORY_TYPE_USER_PTR,
 } GstVaapiBufferMemoryType;
 
 GstVaapiBufferProxy *
@@ -95,12 +101,6 @@ gst_vaapi_buffer_proxy_get_size (GstVaapiBufferProxy * proxy);
 void
 gst_vaapi_buffer_proxy_release_data (GstVaapiBufferProxy * proxy);
 
-void
-gst_vaapi_buffer_proxy_set_mem (GstVaapiBufferProxy * proxy, GstMemory * mem);
-
-GstMemory *
-gst_vaapi_buffer_proxy_peek_mem (GstVaapiBufferProxy * proxy);
-
 G_END_DECLS
 
 #endif /* GST_VAAPI_BUFFER_PROXY_H */
