@@ -671,7 +671,7 @@ op_data_ensure_caps (GstVaapiFilterOpData * op_data, gpointer filter_caps,
       return FALSE;
   }
 
-  op_data->va_caps = g_memdup (filter_cap, op_data->va_cap_size * va_num_caps);
+  op_data->va_caps = g_memdup2 (filter_cap, op_data->va_cap_size * va_num_caps);
   if (!op_data->va_caps)
     return FALSE;
 
@@ -1642,22 +1642,6 @@ gst_vaapi_filter_fill_color_standards (GstVaapiFilter * filter,
   fill_color_standard (&filter->output_colorimetry,
       &pipeline_param->output_color_standard,
       &pipeline_param->output_color_properties);
-
-  /* Handle RGB <-> YUV color primary driver quirk */
-  if (gst_vaapi_display_has_driver_quirks (filter->display,
-          GST_VAAPI_DRIVER_QUIRK_NO_RGBYUV_VPP_COLOR_PRIMARY)) {
-    gboolean src_is_rgb = gst_video_colorimetry_matches
-        (&filter->input_colorimetry, GST_VIDEO_COLORIMETRY_SRGB);
-    gboolean dst_is_rgb = gst_video_colorimetry_matches
-        (&filter->output_colorimetry, GST_VIDEO_COLORIMETRY_SRGB);
-
-    if ((!src_is_rgb && dst_is_rgb) || (src_is_rgb && !dst_is_rgb)) {
-      pipeline_param->output_color_standard = VAProcColorStandardExplicit;
-      pipeline_param->output_color_properties.colour_primaries =
-          gst_video_color_primaries_to_iso (filter->
-          input_colorimetry.primaries);
-    }
-  }
 #else
   pipeline_param->surface_color_standard = VAProcColorStandardNone;
   pipeline_param->output_color_standard = VAProcColorStandardNone;
