@@ -27,7 +27,6 @@
 
 #include "gstvaapiminiobject.h"
 #include "gstvaapisurfaceproxy.h"
-#include "gstvaapiobject_priv.h"
 #include "gstvaapisurface_priv.h"
 
 #define GST_VAAPI_SURFACE_PROXY(obj) \
@@ -48,15 +47,6 @@ struct _GstVaapiSurfaceProxy
   gpointer destroy_data;
   GstVaapiRectangle crop_rect;
   guint has_crop_rect:1;
-
-#if USE_H264_FEI_ENCODER
-  GstVaapiEncFeiMvPredictor *mvpred;
-  GstVaapiEncFeiMbControl *mbcntrl;
-  GstVaapiEncFeiQp *qp;
-  GstVaapiEncFeiMbCode *mbcode;
-  GstVaapiEncFeiMv *mv;
-  GstVaapiEncFeiDistortion *dist;
-#endif
 };
 
 #define GST_VAAPI_SURFACE_PROXY_FLAGS       GST_VAAPI_MINI_OBJECT_FLAGS
@@ -86,7 +76,7 @@ struct _GstVaapiSurfaceProxy
  */
 #undef  GST_VAAPI_SURFACE_PROXY_SURFACE_ID
 #define GST_VAAPI_SURFACE_PROXY_SURFACE_ID(proxy) \
-  (GST_VAAPI_OBJECT_ID (GST_VAAPI_SURFACE_PROXY (proxy)->surface))
+  (GST_VAAPI_SURFACE_ID (GST_VAAPI_SURFACE_PROXY (proxy)->surface))
 
 /**
  * GST_VAAPI_SURFACE_PROXY_VIEW_ID:
