@@ -98,6 +98,19 @@ error_unsupported_format:
   }
 }
 
+void
+gst_vaapi_window_set_vpp_format_internal (GstVaapiWindow * window,
+    GstVideoFormat format, guint flags)
+{
+  if (window->surface_pool_format == format &&
+      window->surface_pool_flags == flags)
+    return;
+
+  gst_vaapi_video_pool_replace (&window->surface_pool, NULL);
+  window->surface_pool_format = format;
+  window->surface_pool_flags = flags;
+}
+
 static gboolean
 ensure_filter_surface_pool (GstVaapiWindow * window)
 {
@@ -109,7 +122,8 @@ ensure_filter_surface_pool (GstVaapiWindow * window)
   /* Ensure VA surface pool is created */
   /* XXX: optimize the surface format to use. e.g. YUY2 */
   window->surface_pool = gst_vaapi_surface_pool_new (display,
-      GST_VIDEO_FORMAT_NV12, window->width, window->height);
+      window->surface_pool_format, window->width, window->height,
+      window->surface_pool_flags);
   if (!window->surface_pool) {
     GST_WARNING ("failed to create surface pool for conversion");
     return FALSE;
@@ -229,6 +243,8 @@ gst_vaapi_window_new_internal (GType type, GstVaapiDisplay * display,
   if (!window)
     return NULL;
 
+  window->surface_pool_format = GST_VIDEO_FORMAT_NV12;
+
   window->use_foreign_window = id != GST_VAAPI_ID_INVALID;
   GST_VAAPI_WINDOW_ID (window) = window->use_foreign_window ? id : 0;
 
@@ -284,7 +300,7 @@ gst_vaapi_window_vpp_convert_internal (GstVaapiWindow * window,
 error_process_filter:
   {
     GST_ERROR ("failed to process surface %" GST_VAAPI_ID_FORMAT " (error %d)",
-        GST_VAAPI_ID_ARGS (GST_VAAPI_OBJECT_ID (surface)), status);
+        GST_VAAPI_ID_ARGS (GST_VAAPI_SURFACE_ID (surface)), status);
     gst_vaapi_video_pool_put_object (window->surface_pool, vpp_surface);
     return NULL;
   }
@@ -397,6 +413,32 @@ gst_vaapi_window_get_fullscreen (GstVaapiWindow * window)
   return window->is_fullscreen;
 }
 
+/**
+ * gst_vaapi_window_set_render_rectangle:
+ * @window: a #GstVaapiWindow
+ * @x: the horizontal offset of the render area inside the window
+ * @y: the vertical offset of the render area inside the window
+ * @width: the width of the render area inside the window
+ * @height: the height of the render area inside the window
+ *
+ * Set information of the render area.
+ *
+ * Since: 1.18
+ */
+void
+gst_vaapi_window_set_render_rectangle (GstVaapiWindow * window, gint x, gint y,
+    gint width, gint height)
+{
+  const GstVaapiWindowClass *klass;
+
+  g_return_if_fail (window != NULL);
+
+  klass = GST_VAAPI_WINDOW_GET_CLASS (window);
+
+  if (klass->set_render_rect)
+    klass->set_render_rect (window, x, y, width, height);
+}
+
 /**
  * gst_vaapi_window_set_fullscreen:
  * @window: a #GstVaapiWindow
@@ -528,10 +570,12 @@ gst_vaapi_window_set_size (GstVaapiWindow * window, guint width, guint height)
   if (!GST_VAAPI_WINDOW_GET_CLASS (window)->resize (window, width, height))
     return;
 
+  GST_VAAPI_WINDOW_LOCK_DISPLAY (window);
   gst_vaapi_video_pool_replace (&window->surface_pool, NULL);
 
   window->width = width;
   window->height = height;
+  GST_VAAPI_WINDOW_UNLOCK_DISPLAY (window);
 }
 
 static inline void
@@ -602,60 +646,6 @@ gst_vaapi_window_put_surface (GstVaapiWindow * window,
   return klass->render (window, surface, src_rect, dst_rect, flags);
 }
 
-static inline void
-get_pixmap_rect (GstVaapiPixmap * pixmap, GstVaapiRectangle * rect)
-{
-  guint width, height;
-
-  gst_vaapi_pixmap_get_size (pixmap, &width, &height);
-  rect->x = 0;
-  rect->y = 0;
-  rect->width = width;
-  rect->height = height;
-}
-
-/**
- * gst_vaapi_window_put_pixmap:
- * @window: a #GstVaapiWindow
- * @pixmap: a #GstVaapiPixmap
- * @src_rect: the sub-rectangle of the source pixmap to
- *   extract and process. If %NULL, the entire pixmap will be used.
- * @dst_rect: the sub-rectangle of the destination
- *   window into which the pixmap is rendered. If %NULL, the entire
- *   window will be used.
- *
- * Renders the @pixmap region specified by @src_rect into the @window
- * region specified by @dst_rect.
- *
- * Return value: %TRUE on success
- */
-gboolean
-gst_vaapi_window_put_pixmap (GstVaapiWindow * window,
-    GstVaapiPixmap * pixmap,
-    const GstVaapiRectangle * src_rect, const GstVaapiRectangle * dst_rect)
-{
-  const GstVaapiWindowClass *klass;
-  GstVaapiRectangle src_rect_default, dst_rect_default;
-
-  g_return_val_if_fail (GST_VAAPI_IS_WINDOW (window), FALSE);
-  g_return_val_if_fail (pixmap != NULL, FALSE);
-
-  klass = GST_VAAPI_WINDOW_GET_CLASS (window);
-  if (!klass->render_pixmap)
-    return FALSE;
-
-  if (!src_rect) {
-    src_rect = &src_rect_default;
-    get_pixmap_rect (pixmap, &src_rect_default);
-  }
-
-  if (!dst_rect) {
-    dst_rect = &dst_rect_default;
-    get_window_rect (window, &dst_rect_default);
-  }
-  return klass->render_pixmap (window, pixmap, src_rect, dst_rect);
-}
-
 /**
  * gst_vaapi_window_reconfigure:
  * @window: a #GstVaapiWindow
