@@ -44,6 +44,9 @@
 #include <gst/vaapi/gstvaapidecoder_vp8.h>
 #include <gst/vaapi/gstvaapidecoder_h265.h>
 #include <gst/vaapi/gstvaapidecoder_vp9.h>
+#if USE_AV1_DECODER
+#include <gst/vaapi/gstvaapidecoder_av1.h>
+#endif
 
 #define GST_PLUGIN_NAME "vaapidecode"
 #define GST_PLUGIN_DESC "A VA-API based video decoder"
@@ -64,18 +67,7 @@ GST_DEBUG_CATEGORY_STATIC (gst_debug_vaapidecode);
 #define GST_CAPS_CODEC(CODEC) CODEC "; "
 
 /* *INDENT-OFF* */
-static const char gst_vaapidecode_sink_caps_str[] =
-    GST_CAPS_CODEC("video/mpeg, mpegversion=2, systemstream=(boolean)false")
-    GST_CAPS_CODEC("video/mpeg, mpegversion=4")
-    GST_CAPS_CODEC("video/x-divx")
-    GST_CAPS_CODEC("video/x-xvid")
-    GST_CAPS_CODEC("video/x-h263")
-    GST_CAPS_CODEC("video/x-h264")
-    GST_CAPS_CODEC("video/x-h265")
-    GST_CAPS_CODEC("video/x-wmv")
-    GST_CAPS_CODEC("video/x-vp8")
-    GST_CAPS_CODEC("video/x-vp9")
-    ;
+char *gst_vaapidecode_sink_caps_str = NULL;
 
 static const char gst_vaapidecode_src_caps_str[] =
     GST_VAAPI_MAKE_SURFACE_CAPS "; "
@@ -118,8 +110,8 @@ static const GstVaapiDecoderMap vaapi_decode_map[] = {
   {GST_VAAPI_CODEC_VP8, GST_RANK_PRIMARY, "vp8", "video/x-vp8", NULL},
   {GST_VAAPI_CODEC_VP9, GST_RANK_PRIMARY, "vp9", "video/x-vp9", NULL},
   {GST_VAAPI_CODEC_H265, GST_RANK_PRIMARY, "h265", "video/x-h265", NULL},
-  {0 /* the rest */ , GST_RANK_PRIMARY + 1, NULL,
-      gst_vaapidecode_sink_caps_str, NULL},
+  {GST_VAAPI_CODEC_AV1, GST_RANK_PRIMARY, "av1", "video/x-av1", NULL},
+  {0 /* the rest */ , GST_RANK_PRIMARY + 1, NULL, NULL, NULL},
 };
 
 static GstElementClass *parent_class = NULL;
@@ -269,9 +261,10 @@ gst_vaapidecode_ensure_allowed_srcpad_caps (GstVaapiDecode * decode)
   gst_caps_set_features_simple (va_caps,
       gst_caps_features_from_string (GST_CAPS_FEATURE_MEMORY_VAAPI_SURFACE));
 
-  if (GST_VAAPI_PLUGIN_BASE_SRC_PAD_CAN_DMABUF (decode)
-      && gst_vaapi_mem_type_supports (mem_types,
-          GST_VAAPI_BUFFER_MEMORY_TYPE_DMA_BUF)) {
+  if (gst_vaapi_mem_type_supports (mem_types,
+          GST_VAAPI_BUFFER_MEMORY_TYPE_DMA_BUF) ||
+      gst_vaapi_mem_type_supports (mem_types,
+          GST_VAAPI_BUFFER_MEMORY_TYPE_DMA_BUF2)) {
     dma_caps = gst_caps_copy (base_caps);
     gst_caps_set_features_simple (dma_caps,
         gst_caps_features_from_string (GST_CAPS_FEATURE_MEMORY_DMABUF));
@@ -979,6 +972,11 @@ gst_vaapidecode_create (GstVaapiDecode * decode, GstCaps * caps)
     case GST_VAAPI_CODEC_VP9:
       decode->decoder = gst_vaapi_decoder_vp9_new (dpy, caps);
       break;
+#if USE_AV1_DECODER
+    case GST_VAAPI_CODEC_AV1:
+      decode->decoder = gst_vaapi_decoder_av1_new (dpy, caps);
+      break;
+#endif
     default:
       decode->decoder = NULL;
       break;
@@ -1302,7 +1300,9 @@ gst_vaapidecode_ensure_allowed_sinkpad_caps (GstVaapiDecode * decode)
         || profile == GST_VAAPI_PROFILE_H265_MAIN_422_10
         || profile == GST_VAAPI_PROFILE_H265_MAIN_444
         || profile == GST_VAAPI_PROFILE_H265_MAIN_444_10
-        || profile == GST_VAAPI_PROFILE_H265_MAIN12) {
+        || profile == GST_VAAPI_PROFILE_H265_MAIN12
+        || profile == GST_VAAPI_PROFILE_H265_MAIN_444_12
+        || profile == GST_VAAPI_PROFILE_H265_MAIN_422_12) {
       gchar *profiles[3], *intra_name;
 
       intra_name = g_strdup_printf ("%s-intra", profile_name);
@@ -1545,7 +1545,7 @@ gst_vaapidecode_class_init (GstVaapiDecodeClass * klass)
       "Gwenole Beauchesne <gwenole.beauchesne@intel.com>, "
       "Halley Zhao <halley.zhao@intel.com>, "
       "Sreerenj Balachandran <sreerenj.balachandran@intel.com>, "
-      "Wind Yuan <feng.yuan@intel.com>");
+      "Wind Yuan <feng.yuan@intel.com>, Junyan He <junyan.he@intel.com>");
 
   g_free (longname);
   g_free (description);
@@ -1554,7 +1554,12 @@ gst_vaapidecode_class_init (GstVaapiDecodeClass * klass)
     map->install_properties (object_class);
 
   /* sink pad */
-  caps = gst_caps_from_string (map->caps_str);
+  if (map->caps_str) {
+    caps = gst_caps_from_string (map->caps_str);
+  } else {
+    caps = gst_caps_from_string (gst_vaapidecode_sink_caps_str);
+    g_free (gst_vaapidecode_sink_caps_str);
+  }
   pad_template = gst_pad_template_new ("sink", GST_PAD_SINK, GST_PAD_ALWAYS,
       caps);
   gst_caps_unref (caps);
@@ -1580,7 +1585,7 @@ gst_vaapidecode_register (GstPlugin * plugin, GArray * decoders)
 {
   gboolean ret = FALSE;
   guint i, codec, rank;
-  gchar *type_name, *element_name;
+  gchar *type_name, *element_name, *sink_caps_str;
   const gchar *name;
   GType type;
   GTypeInfo typeinfo = {
@@ -1603,6 +1608,15 @@ gst_vaapidecode_register (GstPlugin * plugin, GArray * decoders)
     if (codec && !gst_vaapi_codecs_has_codec (decoders, codec))
       continue;
 
+    if (!gst_vaapidecode_sink_caps_str) {
+      gst_vaapidecode_sink_caps_str = g_strdup (vaapi_decode_map[i].caps_str);
+    } else {
+      sink_caps_str = g_strconcat (gst_vaapidecode_sink_caps_str, "; ",
+          vaapi_decode_map[i].caps_str, NULL);
+      g_clear_pointer (&gst_vaapidecode_sink_caps_str, g_free);
+      gst_vaapidecode_sink_caps_str = sink_caps_str;
+    }
+
     if (codec) {
       type_name = g_strdup_printf ("GstVaapiDecode_%s", name);
       element_name = g_strdup_printf ("vaapi%sdec", name);
